@@ -16,7 +16,7 @@
 #
 
 from ai.h2o.sparkling.ml.models import H2OMOJOModel
-from ai.h2o.sparkling.H2ODataFrameConverters import H2ODataFrameConverters
+from ai.h2o.sparkling.ml.params.H2OTypeConverters import H2OTypeConverters
 
 
 class H2OGridSearchExtras:
@@ -26,8 +26,8 @@ class H2OGridSearchExtras:
 
     def getGridModelsParams(self):
         jdf = self._java_obj.getGridModelsParams()
-        return H2ODataFrameConverters.scalaToPythonDataFrame(jdf)
+        return H2OTypeConverters.scalaToPythonDataFrame(jdf)
 
     def getGridModelsMetrics(self):
         jdf = self._java_obj.getGridModelsMetrics()
-        return H2ODataFrameConverters.scalaToPythonDataFrame(jdf)
+        return H2OTypeConverters.scalaToPythonDataFrame(jdf)
