@@ -69,7 +69,10 @@ class H2OGBMRegressor(H2OGBM):
                  minSplitImprovement=1.0E-5,
                  histogramType="AUTO",
                  calibrateModel=False,
+                 calibrationMethod="AUTO",
                  checkConstantResponse=True,
+                 inTrainingCheckpointsDir=None,
+                 inTrainingCheckpointsTreeInterval=1,
                  modelId=None,
                  nfolds=0,
                  keepCrossValidationModels=True,
